Installation of the cb_key_stroke module — cb_key_stroke documentation

# Installation of the cb_key_stroke module

## Pip Installation

cb_key_stroke can easily be installed from the python package index https://pypi.org/project/cb-key-stroke/ by using pip:

Linux

    pip3 install ./cb_key_stroke-<release>-py3-none-any.whl

    or

    pip3 install cb-key-stroke

Max OSX

    pip3 install ./cb_key_stroke-<release>-py3-none-any.whl

    or

    pip3 install ./cb-key-stroke

Windows

    python3 -m pip install cb_key_stroke-<release>-py3-none-any.whl

    or

    python3 -m pip install cb-key-stroke